"use strict";

$(document).ready(() => {

    let settings = getSettings();
    const pathToSfeduAPIAdapter = $('#sync_api_url').html().trim();

    let loadedDisciplines = {};
    let allGroups = {};

    let $groups = $('#json_groups');

    let groupsRaw = $.parseJSON($groups.html() || '{}');
    Object.values(groupsRaw).forEach((value) => {
        value.groups.forEach((group) => {
            let newGroup = {
                groupNum: group.GroupNum,
                groupID: group.ID,
                gradeID: value.grade_id,
                gradeNum: value.grade_num,
            };
            allGroups[group.ID] = newGroup;
        });
    });

    $groups.remove();

    function customMenu(node) {
        var items = {
            export: {
                label: "Выгрузить",
                action: function (obj) {
                    const selected = $('#groupTree').jstree().get_selected();
                    if (selected[0].startsWith("discipline_")) {
                        const singleNumRegexp = /\w_(\d+)/;

                        const parseClass = function (str) {

                            singleNumRegexp.lastIndex = 0;
                            let foundMatch = singleNumRegexp.exec(str);
                            return foundMatch ? parseInt(foundMatch[1]) : 0;

                        };

                        const disciplineID = parseClass(selected[0]);
                        const disciplineInfo = loadedDisciplines[disciplineID];
                        const parent = $('#groupTree').jstree().get_parent(selected);
                        const groupID = parseClass(parent);
                        const groupInfo = allGroups[groupID];
                        //console.log(groupInfo);
                        //console.log(disciplineInfo);
                        const planExtId = "000" + disciplineInfo.PlanExternalID;
                        const disciplineExtId = disciplineInfo.DisciplineExternalID;

                        $.get(pathToSfeduAPIAdapter + '/forms', {
                            year: settings.year.toString()+"-"+(settings.year+1).toString().substr(2,2),
                            semester: settings.semesterNum,
                            plan: planExtId,
                            discipline: disciplineExtId,
                            groupnum: groupInfo.groupNum,
                            gradenum: groupInfo.gradeNum,
                            study_form: 1,
                            faculty: settings.facultyID
                        });
                    }
                }
            },
        };

        if (!node.id.startsWith("discipline_")) {
            // Delete the "delete" menu item
            delete items.export;
        }

        return items;
    }

    $(function () {
            $('#groupTree').jstree(
                {
                    "core": {
                        // so that create works
                        "check_callback": true,
                        error: function (err) {
                            console.log(err);
                        }
                    },
                    "plugins": ["contextmenu"],
                    "contextmenu": {"items": customMenu},
                },
            );
        }
    );

    $('#groupTree').on("changed.jstree", function (e, data) {
        const singleNumRegexp = /\w_(\d+)/;

        const parseClass = function (str) {

            singleNumRegexp.lastIndex = 0;
            let foundMatch = singleNumRegexp.exec(str);
            return foundMatch ? parseInt(foundMatch[1]) : 0;

        };

        let getDisciplines = function (groupID, url, onSuccess, onFail, successText, errorText) {
            $.post(g_URLdir + url, {groupID: groupID}).success((disciplines) => {
                Popup.success(successText);
                onSuccess(JSON.parse(JSON.parse(disciplines).response));
            }).fail(jqXHR => {
                onFail();
                const status = parseInt(jqXHR.status);
                let message = errorText;
                try {
                    if (status === 400)
                        message = JSON.parse(jqXHR.responseText).message;
                } catch (error) {
                }
                if (status !== 0)
                    Popup.error(message);
            });
        };

        if (data.selected[0] && data.selected[0].startsWith("group_")) {
            if (!$('#groupTree').jstree().is_leaf(data.selected)) return;
            let groupID = parseClass(data.selected[0]);

            getDisciplines(groupID, 'handler/discipline/getDisciplinesForGroup',
                function (disciplines) {
                    jQuery.each(disciplines, function (i, val) {
                        loadedDisciplines[i] = val;
                        $('#groupTree').jstree().create_node(data.selected, {
                            "id": "discipline_" + val.ID,
                            "text": val.lastExportDate? val.SubjectName + ", последняя дата: " + val.lastExportDate: val.SubjectName,
                        }, "last");
                    });
                    $('#groupTree').jstree().open_node(data.selected);
                },
                function () {
                }, "дисциплины загрузились", "ошибка");
        } else if (data.selected[0] && data.selected[0].startsWith("discipline_")) {
        }
    })

});
